@@ -68,9 +68,6 @@ pub enum Currency {
     /// Mongolian Tugrik
     Mnt,
 
-    /// Norwegian Krone
-    Nok,
-
     /// IMF Special Drawing Rights
     Sdr,
 
@@ -92,8 +89,9 @@ pub enum Currency {
     /// Swedish Krona
     Sek,
 
-    /*    ///Taiwan Dollar
-    Twd,*/
+    ///Taiwan Dollar
+    Twd,
+
     /// Other (open-ended)
     Other(String),
 }
@@ -128,8 +126,7 @@ impl Display for Currency {
             Currency::Thb => "THB",
             Currency::Sek => "SEK",
             Currency::Dkk => "DKK",
-            Currency::Nok => "NOK",
-            //    Currency::Twd => "TWD",
+            Currency::Twd => "TWD",
         })
     }
 }
@@ -164,8 +161,7 @@ impl FromStr for Currency {
             "THB" => Currency::Thb,
             "SEK" => Currency::Sek,
             "DKK" => Currency::Dkk,
-            "NOK" => Currency::Nok,
-            //    "TWD" => Currency::Twd,
+            "TWD" => Currency::Twd,
             other => Currency::Other(other.to_owned()),
         })
     }
@@ -191,8 +187,7 @@ impl From<Denom> for Currency {
             Denom::Uthb => Currency::Thb,
             Denom::Usek => Currency::Sek,
             Denom::Udkk => Currency::Dkk,
-            Denom::Unok => Currency::Nok,
-            //    Denom::Utwd => Currency::Twd,
+            Denom::Utwd => Currency::Twd,
         }
     }
 }
@@ -243,8 +238,7 @@ impl Currency {
             Currency::Thb => "N/A".to_string(),
             Currency::Sek => "N/A".to_string(),
             Currency::Dkk => "N/A".to_string(),
-            Currency::Nok => "N/A".to_string(),
-            //  Currency::Twd => "N/A".to_string(),
+            Currency::Twd => "N/A".to_string(),
         }
     }
 }
