@@ -70,10 +70,8 @@ pub enum Denom {
     ///Danish Krone
     Udkk,
 
-    /// Norwegian Krone
-    Unok,
-    /*    ///Taiwan Dollar
-    Utwd,*/
+    ///Taiwan Dollar
+    Utwd,
 }
 
 impl Denom {
@@ -97,8 +95,7 @@ impl Denom {
             Denom::Uthb,
             Denom::Usek,
             Denom::Udkk,
-            Denom::Unok,
-            //    Denom::Utwd,
+            Denom::Utwd,
         ]
     }
 
@@ -122,8 +119,7 @@ impl Denom {
             Denom::Uthb => "uthb",
             Denom::Usek => "usek",
             Denom::Udkk => "udkk",
-            Denom::Unok => "unok",
-            //    Denom::Utwd => "utwd",
+            Denom::Utwd => "utwd",
         }
     }
 
@@ -245,8 +241,8 @@ impl FromStr for Denom {
             "uthb" => Ok(Denom::Uthb),
             "usek" => Ok(Denom::Usek),
             "udkk" => Ok(Denom::Udkk),
-            "unok" => Ok(Denom::Unok),
-            //    "utwd" => Ok(Denom::Utwd),
+            "utwd" => Ok(Denom::Utwd),
+
             _ => fail!(ErrorKind::Currency, "unknown Terra denom: {}", s),
         }
     }
